@@ -23,7 +23,7 @@ use POSIX;
 
 use 5.010;
 
-our $VERSION = '0.059'; # VERSION
+our $VERSION = '0.060'; # VERSION
 
 has '_config_key_cache' => ( is => 'rw', default => sub { {} } );
 has '_nfi_cache'        => ( is => 'rw', default => sub { {} } );
@@ -90,6 +90,7 @@ sub _build_config {
   my $conf_f = $self->config_file;
   if ( -f $conf_f ) {
     $conf = yslurp($conf_f);
+  $conf //= {};
 
     confess "configuration file >> $conf_f << is not a hash/dictionary structure"
       if ( ref $conf ne 'HASH' );
@@ -178,16 +179,16 @@ sub conf {
       if ( exists( $data->{$k} ) ) {
         $data = $data->{$k};
       } else {
-        confess "$k not found in gonzconf";
+        $self->log->fatal_confess("$k not found in gonzconf");
       }
     } elsif ( $r && $r eq 'ARRAY' ) {
       if ( exists( $data->[$k] ) ) {
         $data = $data->[$k];
       } else {
-        confess "$k not found in gonzconf";
+        $self->log->fatal_confess("$k not found in gonzconf");
       }
     } else {
-      confess "$k not found in gonzconf";
+      $self->log->fatal_confess("$k not found in gonzconf");
     }
   }
   if (@keys) {
