@@ -14,29 +14,29 @@ use Parallel::ForkManager;
 
 use base 'Exporter';
 our ( @EXPORT, @EXPORT_OK, %EXPORT_TAGS );
-our $VERSION = '0.059'; # VERSION
+our $VERSION = '0.060'; # VERSION
 
 @EXPORT
-  = qw(catfile nfi analysis_version path_to analysis_path gonzlog gonzconf iof $GONZLOG gonzc gonzl gonz_iterate gonzsys);
+  = qw(catfile nfi analysis_version path_to analysis_path gonzlog gonzconf iof gonzc gonzl gonz_iterate gonzsys);
 %EXPORT_TAGS = ();
 @EXPORT_OK   = qw();
 
-my $bgp = Bio::Gonzales::Project->new();
+sub _bgp {
+  state $bgp = Bio::Gonzales::Project->new();
+}
 
-our $GONZLOG = $bgp->log;
-
-sub analysis_version { $bgp->analysis_version(@_) }
-sub path_to          { $bgp->path_to(@_) }
-sub gonzlog          { confess "deprecated call syntax, use gonzl->info" if(@_ > 0 && $_[0]); $bgp->log() }
-sub gonzl            { confess "deprecated call syntax, use gonzl->info" if(@_ > 0 && $_[0]); $bgp->log() }
-sub nfi              { $bgp->nfi(@_) }
-sub iof              { $bgp->conf(@_) }
-sub gonzconf         { $bgp->conf(@_) }
-sub gonzc            { $bgp->conf(@_) }
-sub analysis_path    { $bgp->analysis_path(@_) }
+sub analysis_version { _bgp->analysis_version(@_) }
+sub path_to          { _bgp->path_to(@_) }
+sub gonzlog          { confess "deprecated call syntax, use gonzlog->info" if(@_ > 0 && $_[0]); _bgp->log() }
+sub gonzl            { confess "deprecated call syntax, use gonzl->info" if(@_ > 0 && $_[0]); _bgp->log() }
+sub nfi              { _bgp->nfi(@_) }
+sub iof              { _bgp->conf(@_) }
+sub gonzconf         { _bgp->conf(@_) }
+sub gonzc            { _bgp->conf(@_) }
+sub analysis_path    { _bgp->analysis_path(@_) }
 
 sub gonzsys {
-  $bgp->log->info("(exec) > " . join(" ", @_ ). " <");
+  _bgp->log->info("(exec) > " . join(" ", @_ ). " <");
   system(@_) == 0 or confess "system failed: $?";
 }
 
