@@ -10,11 +10,11 @@ use String::ShellQuote;
 
 use base 'Exporter';
 our ( @EXPORT, @EXPORT_OK, %EXPORT_TAGS );
-our $VERSION = '0.059'; # VERSION
+our $VERSION = '0.060'; # VERSION
 
 @EXPORT      = qw();
 %EXPORT_TAGS = ();
-@EXPORT_OK   = qw(undef_slice slice invslice flatten hash_merge as_arrayref sys_pipe);
+@EXPORT_OK   = qw(undef_slice slice invslice flatten hash_merge as_arrayref sys_pipe sys_fmt);
 
 sub slice {
   my ( $hr, @k ) = @_;
@@ -100,7 +100,7 @@ sub as_arrayref {
   }
 }
 
-sub sys_pipe {
+sub sys_fmt {
   my $cmd;
 
   for my $e (@_) {
@@ -113,6 +113,12 @@ sub sys_pipe {
     }
   }
   chomp $cmd;
+
+  return $cmd;
+}
+
+sub sys_pipe {
+  my $cmd = sys_fmt(@_);
   system($cmd) == 0 or confess "system failed: $?\n$cmd";
 }
 
