@@ -3,7 +3,7 @@ package Bio::Gonzales::Util::Log;
 # shamelessly stolen from Mojo::Log, thanks to Sebastian Riedel & contributors for creating it.
 use Moo;
 
-use Carp 'croak';
+use Carp qw(croak confess);
 use Fcntl ':flock';
 use POSIX qw/strftime/;
 
@@ -12,7 +12,7 @@ use strict;
 
 use 5.010;
 
-our $VERSION = '0.059'; # VERSION
+our $VERSION = '0.060'; # VERSION
 
 # Supported log level
 my $LEVEL = { debug => 1, info => 2, warn => 3, error => 4, fatal => 5 };
@@ -48,7 +48,9 @@ sub error { shift->log( error => @_ ) }
 sub warn  { shift->log( warn  => @_ ) }
 sub fatal { shift->log( fatal => @_ ) }
 
-sub fatal_confess { shift->log(fatal => @_) and confess(@_) }
+sub fatal_confess { shift->log( fatal => @_ ) and confess(@_) }
+sub fatal_die     { shift->log( fatal => @_ ) and die(@_) }
+sub fatal_croak   { shift->log( fatal => @_ ) and croak(@_) }
 
 sub format {
   my ( $self, $level, @lines ) = @_;
@@ -75,7 +77,7 @@ sub is_warn  { shift->is_level('warn') }
 
 sub is_level {
   my ( $self, $level ) = @_;
-  croak "level not specified" unless($level);
+  croak "level not specified" unless ($level);
   return $LEVEL->{ lc $level } >= $LEVEL->{ $ENV{GONZALES_LOG_LEVEL} || $self->level };
 }
 
